==> apache-tinkerpop-3.5.3-src.zip: tinkerpop-3.5.3/gremlin-core/src/test/java/org/apache/tinkerpop/gremlin/jsr223/GremlinLangScriptEngineTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.jsr223;

import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
import org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSource;
import org.apache.tinkerpop.gremlin.structure.util.empty.EmptyGraph;
import org.junit.Test;

import javax.script.Bindings;
import javax.script.ScriptException;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.IsInstanceOf.instanceOf;
import static org.junit.Assert.assertEquals;

public class GremlinLangScriptEngineTest {

    private final static GremlinLangScriptEngine scriptEngine = new GremlinLangScriptEngine();
    private final static GraphTraversalSource g = EmptyGraph.instance().traversal();

    static {
        scriptEngine.put("g", g);
    }

    @Test
    public void shouldEvalGremlinScript() throws ScriptException {
        final Object result = scriptEngine.eval("g.V()");
        assertThat(result, instanceOf(Traversal.Admin.class));
        assertEquals(g.V().asAdmin().getBytecode(), ((Traversal.Admin) result).getBytecode());
    }

    @Test
    public void shouldEvalGremlinBytecode() throws ScriptException {
        final Object result = scriptEngine.eval(g.V().asAdmin().getBytecode(), "g");
        assertThat(result, instanceOf(Traversal.Admin.class));
        assertEquals(g.V().asAdmin().getBytecode(), ((Traversal.Admin) result).getBytecode());
    }
}

==> apache-tinkerpop-3.7.1-src.zip: tinkerpop-3.7.1/gremlin-core/src/test/java/org/apache/tinkerpop/gremlin/jsr223/GremlinLangScriptEngineTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.jsr223;

import org.apache.tinkerpop.gremlin.process.traversal.Traversal;
import org.apache.tinkerpop.gremlin.process.traversal.dsl.graph.GraphTraversalSource;
import org.apache.tinkerpop.gremlin.structure.util.empty.EmptyGraph;
import org.junit.Test;

import javax.script.Bindings;
import javax.script.ScriptException;
import javax.script.SimpleBindings;

import java.util.HashMap;
import java.util.Map;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.core.IsInstanceOf.instanceOf;
import static org.junit.Assert.assertEquals;

public class GremlinLangScriptEngineTest {

    private final static GremlinLangScriptEngine scriptEngine = new GremlinLangScriptEngine();
    private final static GraphTraversalSource g = EmptyGraph.instance().traversal();

    static {
        scriptEngine.put("g", g);
    }

    @Test
    public void shouldEvalGremlinScript() throws ScriptException {
        final Object result = scriptEngine.eval("g.V()");
        assertThat(result, instanceOf(Traversal.Admin.class));
        assertEquals(g.V().asAdmin().getBytecode(), ((Traversal.Admin) result).getBytecode());
    }

    @Test
    public void shouldEvalGremlinScriptWithParameters() throws ScriptException {
        final Bindings b = new SimpleBindings();
        b.put("g", g);
        b.put("x", 100);
        b.put("y", 1000);
        b.put("z", 10000);

        final Object result = scriptEngine.eval("g.V(x, y, z)", b);
        assertThat(result, instanceOf(Traversal.Admin.class));
        assertEquals(g.V(100, 1000, 10000).asAdmin().getBytecode(), ((Traversal.Admin) result).getBytecode());
    }

    @Test
    public void shouldEvalGremlinBytecode() throws ScriptException {
        final Object result = scriptEngine.eval(g.V().asAdmin().getBytecode(), "g");
        assertThat(result, instanceOf(Traversal.Admin.class));
        assertEquals(g.V().asAdmin().getBytecode(), ((Traversal.Admin) result).getBytecode());
    }
}
